LocalPath
================

.. currentmodule:: biskit

.. autoclass:: LocalPath
   :members:
   :show-inheritance:
   :special-members: __init__

   

   
   .. rubric:: Methods Overview

   .. autosummary::
      :nosignatures:
   
   
      ~LocalPath.__init__
      ~LocalPath.absfile
      ~LocalPath.dump
      ~LocalPath.exists
      ~LocalPath.formatted
      ~LocalPath.get_local
      ~LocalPath.get_substitution_dict
      ~LocalPath.get_substitution_pairs
      ~LocalPath.load
      ~LocalPath.local
      ~LocalPath.original
      ~LocalPath.set
      ~LocalPath.set_fragments
      ~LocalPath.set_path
      ~LocalPath.set_string
   
   

   
   
   .. rubric:: Attributes Overview

   .. autosummary::
   
      ~LocalPath.ex_fragment
      ~LocalPath.ex_minpath
      ~LocalPath.exclude_vars
   
   

   
   
   .. raw:: html
      
      <hr>
      <h2>LocalPath Method & Attribute Details</h2>

   
   